@@ -7,7 +7,7 @@ function po_for_file
 {
     case "$1" in
        kerfuffle.xml)
-           echo kerfuffle_xml_mimetypes.po
+           echo ark_xml_mimetypes.po
        ;;
     esac
 }
